USE ChangeTracking
GO


-- Drop and recreate target table
IF EXISTS (SELECT 1 FROM sys.tables WHERE OBJECT_ID('[dbo].[Employees]') IS NOT NULL)
DROP TABLE [dbo].[Employees]

SELECT *
INTO dbo.Employees
FROM [src].[Employees]


-- Add primary key for change tracking
ALTER TABLE dbo.Employees
ADD PRIMARY KEY (EmployeeID)
GO



/*********************************************************************************************************************
										Set up change tracking and tracking table
*********************************************************************************************************************/

-- Create the custom Change_Tracking table

IF NOT EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[etl].[Change_Tracking]') AND type IN (N'U'))
BEGIN
CREATE TABLE [etl].[Change_Tracking](
	[Table_Name] [VARCHAR](100) NOT NULL,
	[Change_Tracking_Version] [BIGINT] NULL,
 CONSTRAINT [PK_ChangeTracking] PRIMARY KEY CLUSTERED 
(
	[Table_Name] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
END
GO


-- Truncate the storage table for Tracking IDs
TRUNCATE TABLE etl.Change_Tracking
GO



USE [master]
GO

-- Enable change tracking on DB
IF NOT EXISTS (SELECT * FROM sys.change_tracking_databases WHERE database_id = DB_ID('ChangeTracking'))
	ALTER DATABASE [ChangeTracking] SET CHANGE_TRACKING = ON (CHANGE_RETENTION = 14 DAYS)
GO

USE [ChangeTracking]
GO 

IF NOT EXISTS (SELECT 1 FROM sys.change_tracking_tables WHERE OBJECT_ID = OBJECT_ID('[dbo].[Employees]'))
	ALTER TABLE [dbo].[Employees] ENABLE CHANGE_TRACKING WITH(TRACK_COLUMNS_UPDATED = On)
GO


USE ChangeTracking
GO


DELETE etl.[Change_Tracking]
WHERE Table_Name = 'dbo.Employees'

-- Capture the current value for this table
INSERT etl.[Change_Tracking]
SELECT 'dbo.Employees', CHANGE_TRACKING_CURRENT_VERSION()
