USE ChangeTracking
GO

-- Drop and recreate target table
IF EXISTS (SELECT 1 FROM sys.tables WHERE OBJECT_ID('[dbo].[Employees]') IS NOT NULL)
DROP TABLE [dbo].[Employees]

SELECT *
INTO dbo.Employees
FROM [src].[Employees]


-- Add primary key for change tracking
ALTER TABLE dbo.Employees
ADD PRIMARY KEY (EmployeeID)
GO

IF NOT EXISTS (SELECT 1 FROM sys.change_tracking_tables WHERE OBJECT_ID = OBJECT_ID('[dbo].[Employees]'))
	ALTER TABLE [dbo].[Employees] ENABLE CHANGE_TRACKING WITH(TRACK_COLUMNS_UPDATED = On)
GO


DECLARE @CTVer BIGINT
DECLARE @CTNewVer BIGINT = 0

DELETE etl.[Change_Tracking]
WHERE Table_Name = 'dbo.Employees'

-- Capture the current value for this table
INSERT etl.[Change_Tracking]
SELECT 'dbo.Employees', CHANGE_TRACKING_CURRENT_VERSION()

SELECT @CTNewVer = CHANGE_TRACKING_CURRENT_VERSION()

SELECT @CTVer = Change_Tracking_Version 
FROM etl.[Change_Tracking]
WHERE Table_Name = 'dbo.Employees'

-- Any changes?
SELECT * 
FROM CHANGETABLE(CHANGES dbo.Employees, @CTVer) ct
WHERE SYS_CHANGE_VERSION <= @CTNewVer

/*
	Perform an update on this table
*/

UPDATE dbo.Employees
SET Active = 0
WHERE EmployeeType = 'T'

SELECT @CTNewVer = CHANGE_TRACKING_CURRENT_VERSION()

-- Now show the updated values
SELECT @CTVer = Change_Tracking_Version 
FROM etl.[Change_Tracking]
WHERE Table_Name = 'dbo.Employees'

UPDATE etl.[Change_Tracking]
SET Change_Tracking_Version = @CTNewVer
WHERE Table_Name = 'dbo.Employees'

SELECT * 
FROM CHANGETABLE(CHANGES dbo.Employees, @CTVer) ct
WHERE SYS_CHANGE_VERSION <= @CTNewVer


/*
	Insert
*/
INSERT dbo.Employees (EmployeeID, EmployeeType, FirstName, MiddleName, LastName, EmailPromotion, ModifiedDate, Active)
SELECT 23 EmployeeID, 'T' EmployeeType, 'Byron' [FirstName], 'Arthur' [MiddleName], 'Smith' [LastName], 0 [EmailPromotion], GETDATE() [ModifiedDate], 0 [Active]     
UNION ALL SELECT 28, 'T', 'Elizabeth', 'Ann', 'Nichols', 0, GETDATE(), 0
UNION ALL SELECT 33, 'T', 'Casey', 'Dawn', 'Arthur', 0, GETDATE(), 0

SELECT @CTNewVer = CHANGE_TRACKING_CURRENT_VERSION()

-- Show Values
SELECT @CTVer = Change_Tracking_Version 
FROM etl.[Change_Tracking]
WHERE Table_Name = 'dbo.Employees'

UPDATE etl.[Change_Tracking]
SET Change_Tracking_Version = @CTNewVer
WHERE Table_Name = 'dbo.Employees'

SELECT * 
FROM CHANGETABLE(CHANGES dbo.Employees, @CTVer) ct
WHERE SYS_CHANGE_VERSION <= @CTNewVer

/*
	Delete
*/
DELETE FROM dbo.Employees
WHERE EmployeeID IN (741561, 741567, 741568, 741572, 741579
	, 741589, 741590, 741593, 741609)

SELECT @CTNewVer = CHANGE_TRACKING_CURRENT_VERSION()

-- Show Values
SELECT @CTVer = Change_Tracking_Version 
FROM etl.[Change_Tracking]
WHERE Table_Name = 'dbo.Employees'

UPDATE etl.[Change_Tracking]
SET Change_Tracking_Version = @CTNewVer
WHERE Table_Name = 'dbo.Employees'

SELECT * 
FROM CHANGETABLE(CHANGES dbo.Employees, @CTVer) ct
WHERE SYS_CHANGE_VERSION <= @CTNewVer